import math
import random

import pyglet
from pyglet.window import key, mouse

from .game_consts import MAP_WIDTH, MAP_HEIGHT, CRITTER_SPEED_MINMAX

class Critter(pyglet.sprite.Sprite):
    def __init__(self, img):

        # x = random.random() * 10000 - 5000
        # y = random.random() * 10000 - 5000
        x = random.randint(0, MAP_WIDTH)
        y = random.randint(0, MAP_HEIGHT)
        super().__init__(img, x, y)
        self.speed = random.randrange(*CRITTER_SPEED_MINMAX)
        self.hp = { False: 100, True: 100 }
        self._new_target()

    def _new_target(self):
        # self.target_x = random.random() * 10000 - 5000
        # self.target_y = random.random() * 10000 - 5000
        self.target_x = random.randint(0, MAP_WIDTH)
        self.target_y = random.randint(0, MAP_HEIGHT)
        
    def set_window_dimensions(self, window_width: int, window_height: int):
        self.window_width = window_width
        self.window_height = window_height
    
    def damage(self, evil):
        self.hp[evil] -= 1

    def update(self, dt: float):

        angle = math.atan2(self.target_y - self.y, self.target_x - self.x)
        move_delta = self.speed * dt
        x = self.x + move_delta * math.cos(angle)
        y = self.y + move_delta * math.sin(angle)

        super().update(x=x, y=y, rotation=-angle*180/math.pi)

        dist_from_target_sq = (x - self.target_x) * (x - self.target_x) + (y - self.target_y) * (y - self.target_y)

        if dist_from_target_sq < 100:
            self._new_target()

        