import attr

import pyglet
from pyglet.window import key

from typing import Callable

@attr.s
class MenuItem:
    text: str = attr.ib()
    function: Callable[[], None] = attr.ib()


class Menu(key.KeyStateHandler):
    def __init__(self, items: list[MenuItem], batch, window_width, window_height):
        self.font_size=20
        self.selected = 0
        self.items = items

        self.menu_labels = [
            pyglet.text.Label(
                text=item.text,
                font_size=self.font_size,
                bold=True,
                color=(0, 0, 0, 255) if i != self.selected else (200, 200, 200, 255),
                x=0,
                y=-100 * i,
                anchor_x='center',
                anchor_y='top',
                batch=batch
            )
            for i, item in enumerate(items)
        ]

        self.showing = False

    def _update_menu_items(self):
        for i, menu_label in enumerate(self.menu_labels):
            menu_label.color = (0, 0, 0, 255) if i != self.selected else (200, 200, 200, 255)
    
    def update(self, dt: float):
        pass

    def on_key_press(self, symbol, modifiers):
        if symbol == key.W:
            if self.selected > 0:
                self.selected -= 1
                self._update_menu_items()
        elif symbol == key.S:
            if self.selected < len(self.items) - 1:
                self.selected += 1
                self._update_menu_items()
        elif symbol == key.ENTER:
            self.items[self.selected].function()
        elif symbol == key.ESCAPE:
            self.items[0].function()

        return pyglet.event.EVENT_HANDLED

    def show(self):
        self.showing = True

    def hide(self):
        self.showing = False