import math

import pyglet
from pyglet.window import key, mouse

from . import twin
from .game_consts import MAP_HEIGHT, MAP_WIDTH

class Player(twin.Twin, key.KeyStateHandler):
    def __init__(self, img, x: int, y: int):
        super().__init__(img, x, y, evil=False)

    def set_window_dimensions(self, window_width: int, window_height: int):
        self.window_width = window_width
        self.window_height = window_height

    def on_mouse_motion(self, x, y, dx, dy):
        x_from_centre = x - 0.5 * self.window_width
        y_from_centre = y - 0.5 * self.window_height
        self.rotation = -math.atan2(y_from_centre, x_from_centre) * 180 / math.pi

    def on_mouse_drag(self, x, y, dx, dy, buttons, modifiers):
        if buttons & mouse.LEFT:
            self.on_mouse_motion(x, y, dx, dy)

    def update(self, dt: float):
        move_dist = self.speed * dt
        wall_gap = 30
        if self[key.A]:
            if self.x - move_dist > wall_gap:
                self.x -= move_dist
        elif self[key.D]:
            if self.x + move_dist < MAP_WIDTH - wall_gap:
                self.x += move_dist

        if self[key.W]:
            if self.y + move_dist < MAP_HEIGHT - wall_gap:
                self.y += move_dist
        elif self[key.S]:
            if self.y - move_dist > wall_gap:
                self.y -= move_dist
    


