import math
import random
from typing import Tuple

import pyglet
from pyglet.window import key, mouse

from .game_consts import MAP_WIDTH, MAP_HEIGHT

class Twin(pyglet.sprite.Sprite):
    def __init__(self, img, x: int, y: int, evil: bool):
        super().__init__(img, x, y)
        self.evil = evil
        self.speed = 300.0
        self.beam_on = False
        self.beam_length = 1000.0
        self.evil = evil
        if evil:
            self.beam_colour = (200, 0, 0, 100)
            self._new_target()
            self.beam_on = True
        else:
            self.beam_colour = (200, 200, 0, 100)

    def _new_target(self):
        # self.target_x = random.random() * 10000 - 5000
        # self.target_y = random.random() * 10000 - 5000
        self.target_x = random.randint(0, MAP_WIDTH)
        self.target_y = random.randint(0, MAP_HEIGHT)

    def set_window_dimensions(self, window_width: int, window_height: int):
        self.window_width = window_width
        self.window_height = window_height

    def update(self, dt: float):
        angle = math.atan2(self.target_y - self.y, self.target_x - self.x)
        x = self.x + self.speed * dt * math.cos(angle)
        y = self.y + self.speed * dt * math.sin(angle)

        super().update(x=x, y=y, rotation=-angle*180/math.pi)

        dist_from_target_sq = (x - self.target_x) * (x - self.target_x) + (y - self.target_y) * (y - self.target_y)

        if dist_from_target_sq < 100:
            self._new_target()

    def start_beam(self):
        self.beam_on = True

    def stop_beam(self):
        self.beam_on = False

    def draw(self):
        super().draw()

        if self.beam_on:
            pyglet.graphics.draw(3, pyglet.gl.GL_TRIANGLES, 
            ('v2f', (
                self.x, 
                self.y,
                self.x + self.beam_length * math.cos((self.rotation + 15) * math.pi / 180.0), 
                self.y - self.beam_length * math.sin((self.rotation + 15) * math.pi / 180.0),
                self.x + self.beam_length * math.cos((self.rotation - 15) * math.pi / 180.0), 
                self.y - self.beam_length * math.sin((self.rotation - 15) * math.pi / 180.0), 
            )),
            ('c4B', 
                (self.beam_colour*3)
            ),
        )